]> git.ipfire.org Git - ipfire-2.x.git/blobdiff - make.sh
core129: Ship updated less
[ipfire-2.x.git] / make.sh
diff --git a/make.sh b/make.sh
index 39a1c5380841a3ada47c7d156c5080fe90747064..f4e2bfc56f8be68124364715ee85655178e97e1e 100755 (executable)
--- a/make.sh
+++ b/make.sh
@@ -202,9 +202,9 @@ configure_build() {
 
        # Determine parallelism
        # We assume that each process consumes about
# 192MB of memory. Therefore we find out how
        # many processes fit into memory.
-       local mem_max=$(( ${SYSTEM_MEMORY} / 192 ))
+       local mem_max=$(( ${SYSTEM_MEMORY} / 128 ))
        local cpu_max=$(( ${SYSTEM_PROCESSORS} + 1 ))
 
        local parallelism
@@ -1587,6 +1587,7 @@ buildipfire() {
   lfsmake2 libedit
   lfsmake2 knot
   lfsmake2 spectre-meltdown-checker
+  lfsmake2 zabbix_agentd
 }
 
 buildinstaller() {
@@ -202,9 +202,9 @@ configure_build() {
        # Determine parallelism
        # We assume that each process consumes about
-       # 192MB of memory. Therefore we find out how
+       # 128MB of memory. Therefore we find out how
        # many processes fit into memory.